@@ -7,8 +7,11 @@ MARSS <- function(y,
                   fit = TRUE,
                   silent = FALSE,
                   control = NULL,
-                  fun.kf = "MARSSkfas",
+                  fun.kf = c("MARSSkfas", "MARSSkfss"),
                   ...) {
+  # If user did not pass in fun.kf, then MARSSkfas will be used by default. MARSSkfss will be tried if that fails
+  if (missing(fun.kf)) missing.fun.kf <- FALSE else missing.fun.kf <- TRUE
+  fun.kf <- match.arg(fun.kf)
   allowed.methods <- get("allowed.methods", envir = pkg_globals)
   # Some error checks depend on an allowable method
   if (!method %in% allowed.methods) {
@@ -22,20 +25,24 @@ MARSS <- function(y,
   if (is.null(y)) {
     stop("MARSS: No data (y) passed in.", call. = FALSE)
   }
-  if (is.ts(y)) {
-    stop("MARSS: Please convert the ts object to a matrix with time going across columns.\nThis command will work to convert the data: t(as.data.frame.ts(y)).\nThis command will make a row of the frequency info (if you need this as a covariate): t(as.data.frame.ts(stats:::cycle.ts(y))).\nType MARSSinfo(\"ts\") for more info.", call. = FALSE)
-  }
-  if (!(is.vector(y) | is.matrix(y))) stop("MARSS: Data (y) must be a vector or matrix (time going across columns).", call. = FALSE)
+  if (!(is.vector(y) | is.matrix(y) | inherits(y, "ts"))) stop("MARSS: Data (y) must be a vector, matrix (time going across columns) or ts/mts object.", call. = FALSE)
   if (length(y) == 0) stop("MARSS: Data (y) is length 0.", call. = FALSE)
   if (is.vector(y)) y <- matrix(y, nrow = 1)
+  if (inherits(y, "ts")) {
+    model.tsp <- stats::tsp(y)
+    y <- t(y)
+  } else {
+    model.tsp <- c(1, ncol(y), 1)
+  }
+  attr(y, "model.tsp") <- model.tsp
   if (any(is.nan(y))) cat("MARSS: NaNs in data are being replaced with NAs.  There might be a problem if NaNs shouldn't be in the data.\nNA is the normal missing value designation.\n")
   y[is.na(y)] <- as.numeric(NA)
-  
-  if(inherits(model, "marssMLE")) model <- coef(model, type="matrix")
-  if(inherits(model, "marssMODEL")) model <- marssMODEL.to.list(model)
-  
+
+  if (inherits(model, "marssMLE")) model <- c(coef(model, type = "matrix"), tinitx=model$model$tinitx, diffuse=model$model$diffuse)
+  if (inherits(model, "marssMODEL")) model <- c(marssMODEL.to.list(model), tinitx=model$tinitx, diffuse=model$diffuse)
+
   MARSS.call <- list(data = y, inits = inits, model = model, control = control, method = method, form = form, silent = silent, fit = fit, fun.kf = fun.kf, ...)
-  
+
   # First make sure specified equation form has a corresponding function to do the conversion to marssMODEL (form=marss) object
   as.marss.fun <- paste("MARSS.", form[1], sep = "")
   tmp <- try(exists(as.marss.fun, mode = "function"), silent = TRUE)
@@ -44,7 +51,7 @@ MARSS <- function(y,
     cat("\n", "Errors were caught in MARSS \n", msg, sep = "")
     stop("Stopped in MARSS() due to problem(s) with required arguments.\n", call. = FALSE)
   }
-  
+
   # Build the marssMODEL object from the model argument to MARSS()
   ## The as.marss.fun() call adds the following to MARSS.inputs list:
   ## $marss Translate model strucuture names (shortcuts) into a marssMODEL (form=marss) object put in $marss
@@ -57,7 +64,7 @@ MARSS <- function(y,
   MARSS.inputs <- eval(call(as.marss.fun, MARSS.call))
   marss.object <- MARSS.inputs$marss
   if (silent == 2) cat(paste("Resulting model has ", attr(marss.object, "model.dims")$x[1], " state processes and ", attr(marss.object, "model.dims")$y[1], " observation processes.\n", sep = ""))
-  
+
   ## Check that the marssMODEL object output by MARSS.form() is ok
   ## More checking on the control list is done by is.marssMLE() to make sure the MLEobj is ready for fitting
   if (!identical(MARSS.call$control$trace, -1)) { # turn off all error checking
@@ -73,7 +80,7 @@ MARSS <- function(y,
       if (silent == 2) cat("  marssMODEL is ok.\n")
     }
   }
-  
+
   ## checkMARSSInputs() call does the following:
   ## Check that the user didn't pass in any illegal arguments
   ## and fill in defaults if some params left off
@@ -81,39 +88,40 @@ MARSS <- function(y,
   ## via the MARSS.form() function above
   if (silent == 2) cat("Running checkMARSSInputs().\n")
   MARSS.inputs <- checkMARSSInputs(MARSS.inputs, silent = FALSE)
-  
-  
+
+
   ###########################################################################################################
   ##  MODEL FITTING
   ###########################################################################################################
-  
+
   ## MLE estimation
   kem.methods <- get("kem.methods", envir = pkg_globals)
   optim.methods <- get("optim.methods", envir = pkg_globals)
   if (method %in% c(kem.methods, optim.methods)) {
-    
+
     ## Create the marssMLE object
-    
+
     MLEobj <- list(marss = marss.object, model = MARSS.inputs$model, control = c(MARSS.inputs$control, silent = silent), method = method, fun.kf = fun.kf)
     # Set the call form since that info needed for MARSSinits
     if (MLEobj$control$trace != -1) {
       MLEobj$call <- MARSS.call
     }
-    
+
     # This is a helper function to set simple inits for a marss MLE model object
+    if (silent == 2) cat("Running MARSSinits() to set start conditions.\n")
     MLEobj$start <- MARSSinits(MLEobj, MARSS.inputs$inits)
-    
+
     class(MLEobj) <- "marssMLE"
-    
+
     ## Check the marssMLE object
     ## is.marssMLE() calls is.marssMODEL() to check the model,
     ## then checks dimensions of initial value matrices.
     ## it also checks the control list and add defaults if some values are NULL
-    if(MLEobj$control$trace != -1){
+    if (MLEobj$control$trace != -1) {
       if (silent == 2) cat("Checking the marssMLE object before fitting.\n")
       tmp <- is.marssMLE(MLEobj)
     }
-    
+
     # if errors, tmp will not be true, it will be error messages
     if (!isTRUE(tmp)) {
       if (!silent || silent == 2) {
@@ -125,78 +133,113 @@ MARSS <- function(y,
       return(MLEobj)
     }
     
-    if (MLEobj$control$trace != -1) {
+    # MLEobj is ok.
+    
+    if (!fit){
+      # will be set to 3 if all fixed
+      MLEobj$convergence <- -1
+    }
+    
+    # If all parameters fixed. Set convergence=3 whether or not fit=TRUE
+    model.is.fixed <- FALSE
+    if (all(unlist(lapply(MLEobj[["marss"]][["free"]], is.fixed)))) {
+      model.is.fixed <- TRUE
+      if (silent == 2) cat("All parameters fixed. No estimation done.\n")
+      MLEobj$convergence <- 3
+      MLEobj$par <- list()
+      for (el in attr(MLEobj[["marss"]], "par.names")) MLEobj[["par"]][[el]] <- matrix(0, 0, 1)
+      kf.out <- try(MARSSkf(MLEobj, only.logLik=TRUE), silent = TRUE)
+      if (inherits(kf.out, "try-error")){
+        MLEobj$convergence <- 53
+        MLEobj$logLik <- NA
+      }else{
+        # rest of the output will be added below
+        MLEobj$logLik <- kf.out$logLik
+        kf.out <- try(MARSSkf(MLEobj), silent = TRUE)
+        if (inherits(kf.out, "try-error")){
+          MLEobj$convergence <- 54
+        }
+      }
+    }
+
+    # If fitting is needed, check that Kalman filter/smoother will run
+    if (fit && MLEobj$control$trace != -1 && !model.is.fixed) {
       MLEobj.test <- MLEobj
       MLEobj.test$par <- MLEobj$start
-      # Do this test with MARSSkfss since it has internal tests for problems
-      kftest <- try(MARSSkfss(MLEobj.test), silent = TRUE)
+      kftest <- try(MARSSkf(MLEobj.test), silent = TRUE)
       if (inherits(kftest, "try-error")) {
-        cat("Error: Stopped in MARSS() before fitting because MARSSkfss stopped.  Something is wrong with \n the model structure that prevents Kalman filter running.\n Try using control$trace=-1 and fit=FALSE and then look at the model that MARSS is trying to fit.\n")
+        cat("Error: Stopped in MARSS() before fitting because", fun.kf, "stopped.  Something in the model structure prevents the Kalman filter/smoother (KF) from running.\n Try setting fun.kf to use a different KF function (MARSSkfss or MARSSkfas) or use fit=FALSE and check the model you are trying to fit. You can also try trace=1 to get more progress output. You could try trace=-1 to bypass the initial KF check if you are using method='BFGS' and know the logLik function will run.\n")
         MLEobj$convergence <- 2
         return(MLEobj.test)
       }
       if (!kftest$ok) {
         cat(kftest$msg)
-        cat(paste("Error: Stopped in MARSS() before fitting because the MARSSkfss (Kalman filter) function returned errors.  Something is wrong with \n the model structure. Try using control$trace=-1 and fit=FALSE and then \n look at the model that MARSS is trying to fit.\n", kftest$errors, "\n", sep = ""))
+        cat(paste("Error: Stopped in MARSS() before fitting because", fun.kf, "stopped.  Something in the model structure prevents the Kalman filter or smoother running.\n Try setting fun.kf to use a different KF function (MARSSkfss or MARSSkfas) or use fit=FALSE and check the model you are trying to fit. You can also try trace=1 to get more progress output.\n", kftest$errors, "\n", sep = ""))
         MLEobj$convergence <- 2
         return(MLEobj.test)
       }
       MLEobj.test$kf <- kftest
     }
     # Ey is needed for method=kem
-    if (MLEobj$control$trace != -1 & MLEobj$method == "kem") {
+    if (fit && !model.is.fixed && MLEobj$control$trace != -1 && MLEobj$method %in% kem.methods) {
       Eytest <- try(MARSShatyt(MLEobj.test), silent = TRUE)
       if (inherits(Eytest, "try-error")) {
-        cat("Error: Stopped in MARSS() before fitting because MARSShatyt stopped.  Something is wrong with \n model structure that prevents MARSShatyt running.\n\n")
+        cat("Error: Stopped in MARSS() before fitting because MARSShatyt() stopped.  Something is wrong with the model structure that prevents MARSShatyt() running.\n\n")
         MLEobj.test$convergence <- 2
         MLEobj.test$Ey <- Eytest
         return(MLEobj.test)
       }
       if (!Eytest$ok) {
         cat(Eytest$msg)
-        cat("Error: Stopped in MARSS() before fitting because MARSShatyt returned errors.  Something is wrong with \n model structure that prevents function running.\n\n")
+        cat("Error: Stopped in MARSS() before fitting because MARSShatyt returned errors.  Something is wrong with the model structure that prevents function running.\n\n")
         MLEobj.test$convergence <- 2
         MLEobj.test$Ey <- Eytest
         return(MLEobj.test)
       }
-      # MLEobj$Ey=Eytest
     }
     
-    if (!fit) MLEobj$convergence <- 3
-    
-    if (fit) {
-      ## If no parameters are estimated, then set par element and get the states
-      if (all(unlist(lapply(MLEobj$marss$free, is.fixed)))) {
-        MLEobj$convergence <- 3
-        MLEobj$par <- list()
-        for (el in attr(MLEobj$marss, "par.names")) MLEobj$par[[el]] <- matrix(0, 0, 1)
-      } else { # there is something to estimate
+    # fit and not all parameters estimated
+    if (fit && !model.is.fixed) {
         if (silent == 2) cat(paste("Fitting model with ", method, ".\n", sep = ""))
         ## Fit and add param estimates to the object
-        if (method %in% kem.methods) MLEobj <- MARSSkem(MLEobj)
+        if (method %in% kem.methods) {
+          MLEobj <- try(MARSSkem(MLEobj), silent = TRUE)
+          if (inherits(MLEobj, "try-error")) {
+            cat(paste("Error: Stopped in MARSS() before fitting because MARSSkem returned errors.  Try control$trace=1 for more information as the reported error may not be helpful. You can also try method='BFGS' if you are seeing a 'chol' error.\n", MLEobj[1], "\n"))
+            MLEobj.test$convergence <- 2
+            return(MLEobj.test)
+          }
+        }
         if (method %in% optim.methods) MLEobj <- MARSSoptim(MLEobj)
       }
-      
+
       ## Add AIC and AICc and coef to the object
-      ## Return as long as something was estimated and there are no errors, but might not be converged
-      # If all params fixed (so no fitting), convergence==3
-      if ((MLEobj$convergence %in% c(0, 1)) || (MLEobj$convergence %in% c(10, 11) && method %in% kem.methods)) {
+      ## Return as long as $par element and there are no errors, but might not be converged
+      if ((MLEobj$convergence %in% c(0, 1, 3, 54)) || (MLEobj$convergence %in% c(10, 11) && method %in% kem.methods)) {
+        if (silent == 2) cat("Adding AIC and coefficients.\n")
         MLEobj <- MARSSaic(MLEobj)
         MLEobj$coef <- coef(MLEobj, type = "vector")
       }
+
       ## Add states.se and ytT.se if no errors.  Return kf and Ey if trace>0
-      if ((MLEobj$convergence %in% c(0, 1, 3)) || (MLEobj$convergence %in% c(10, 11) && method %in% kem.methods)) {
-        kf <- MARSSkf(MLEobj) # use function requested by user
-        if (fun.kf == "MARSSkfas") kfss <- MARSSkfss(MLEobj) else kfss <- kf
+      if (MLEobj$convergence %in% c(0, 1, 3) || (MLEobj$convergence %in% c(10, 11) && MLEobj$method %in% kem.methods)) {
+        if (silent == 2) cat("Adding states and states.se.\n")
+        kf <- MARSSkf(MLEobj) # use function requested by user; default smoother=TRUE
         MLEobj$states <- kf$xtT
         MLEobj$logLik <- kf$logLik
-        if (!is.null(kfss[["VtT"]])) {
+        if (!is.null(kf[["VtT"]])) {
           m <- attr(MLEobj$marss, "model.dims")[["x"]][1]
           TT <- attr(MLEobj$marss, "model.dims")[["data"]][2]
-          states.se <- apply(kfss[["VtT"]], 3, function(x) {
-            takediag(x)
-          })
-          states.se[states.se < 0] <- NA
+          states.se <- apply(kf[["VtT"]], 3, function(x) takediag(x))
+          # KFS 
+          if( any(states.se < 0 & states.se > -1*sqrt(.Machine$double.eps)) ){
+            states.se[states.se < 0 & states.se > -1*sqrt(.Machine$double.eps)] <- 0
+            MLEobj$errors <- c(MLEobj$errors, paste("\nAlert:", MLEobj$fun.kf, "returned negative values close to machine tolerance on diagonal of VtT and the states.se values for these are set to 0. You may want to use", ifelse(MLEobj$fun.kf=='MARSSkfas', 'MARSSkfss()', 'MARSSkfas()'), "to compute the states standard errors (states.se). See MARSSinfo('negVt') for insight.\n"))
+          } 
+          if( any(states.se < 0) ){
+            states.se[states.se < 0] <- NA
+            MLEobj$errors <- c(MLEobj$errors, paste("\nAlert:", MLEobj$fun.kf, "returned negative values on diagonal of VtT and the states.se values for these are set to NA. You may want to use", ifelse(MLEobj$fun.kf=='MARSSkfas', 'MARSSkfss()', 'MARSSkfas()'), "to compute the states standard errors (states.se). See MARSSinfo('negVt') for insight.\n"))
+          } 
           states.se <- sqrt(states.se)
           if (m == 1) states.se <- matrix(states.se, 1, TT)
           rownames(states.se) <- attr(MLEobj$marss, "X.names")
@@ -221,33 +264,50 @@ MARSS <- function(y,
           ytT.se <- NULL
         }
         MLEobj$ytT.se <- ytT.se
-        if (MLEobj$control$trace > 0) { # then return kf and Ey
+
+        # Return kf and Ey, if trace = 1
+        if (MLEobj$control$trace > 0) {
+          if (fun.kf == "MARSSkfas") {
+            kfss <- try(MARSSkfss(MLEobj, smoother = FALSE), silent = TRUE)
+            if (inherits(kfss, "try-error") || !kfss$ok) {
+              msg <- "Not available. MARSSkfss() returned error."
+              kfss <- list(Innov = msg, Sigma = msg, J = msg, Kt = msg)
+            }
+          } else {
+            kfss <- kf
+          }
           MLEobj$kf <- kf # from above will use function requested by user
-          # except these are only returned by MARSSkfss
+          MLEobj$Ey <- Ey # from above
+          # these are only returned by MARSSkfss
           MLEobj$Innov <- kfss$Innov
           MLEobj$Sigma <- kfss$Sigma
-          MLEobj$Vtt <- kfss$Vtt
-          MLEobj$xtt <- kfss$xtt
           MLEobj$J <- kfss$J
-          MLEobj$J0 <- kfss$J0
           MLEobj$Kt <- kfss$Kt
-          MLEobj$Ey <- MARSShatyt(MLEobj)
+          if (fun.kf == "MARSSkfss") {
+            MLEobj$J0 <- kfss$J0
+          } else {
+            # From kfss smoother so won't be available if fun.kf=MARSSkfas
+            # Line above used smoother = FALSE; here smoother = TRUE
+            J0 <- try(MARSSkfss(MLEobj), silent = TRUE)
+            if (!inherits(J0, "try-error") && J0$ok) MLEobj$J0 <- J0$J0 else MLEobj$J0 <- "Not available. MARSSkfss() smoother returned error."
+          }
         }
         # apply X and Y names various X and Y related elements
         MLEobj <- MARSSapplynames(MLEobj)
       }
-    } # fit the model
-    
-    if ((!silent || silent == 2) & MLEobj$convergence %in% c(0, 1, 3, 10, 11, 12)) {
+    # END Adding info to output #################
+
+    if ((!silent || silent == 2) && MLEobj[["convergence"]] %in% c(0, 1, 3, 10, 11, 12, 54)) {
       print(MLEobj)
     }
-    if ((!silent || silent == 2) & !(MLEobj$convergence %in% c(0, 1, 3, 10, 11, 12))) {
+    if ((!silent || silent == 2) && !(MLEobj[["convergence"]] %in% c(0, 1, 3, 10, 11, 12, 54))) {
       cat(MLEobj$errors)
     } # 3 added since don't print if fit=FALSE
-    if ((!silent || silent == 2) & !fit) print(MLEobj$model)
-    
+    if ((!silent || silent == 2) && !fit) 
+      print(MLEobj$model)
+
     return(MLEobj)
   } # end MLE methods
-  
+
   return("method allowed but it's not in kem.methods or optim.methods so marssMLE object was not created")
 }
