@@ -5,18 +5,26 @@
 #  residuals_dfa is just residuals_marxss
 ##############################################################################################################################################
 residuals.marssMLE <- function(object, ...,
-                               type=c("tt1", "tT", "tt"),
-                               standardization=c("Cholesky", "marginal", "Block.Cholesky"),
+                               type = c("tt1", "tT", "tt"),
+                               standardization = c("Cholesky", "marginal", "Block.Cholesky"),
                                form = attr(object[["model"]], "form")[1],
                                clean = TRUE) {
   ## Argument checking
   type <- match.arg(type)
   standardization <- match.arg(standardization)
+  if (is.null(object[["par"]])) {
+    stop("residuals.marssMLE: The marssMLE object does not have the par element.  Most likely the model has not been fit.", call. = FALSE)
+  }
+  if (object[["convergence"]] == 54) {
+    stop("residuals.marssMLE: MARSSkf (the Kalman filter/smoother) returns an error with the fitted model. Try MARSSinfo('optimerror54') for insight.", call. = FALSE)
+  }
   
+
   resids.fun <- paste("residuals_", form, sep = "")
   tmp <- try(exists(resids.fun, mode = "function"), silent = TRUE)
   if (isTRUE(tmp)) {
-    ret <- eval(call(resids.fun, object, type = type, standardization = standardization, clean=clean))
+    ret <- try(eval(call(resids.fun, object, type = type, standardization = standardization, clean = clean)), silent = TRUE)
+    if (inherits(ret, "try-error")) stop("Stopped in residuals.marssMLE: MARSSresiduals() failed. \n", call. = FALSE)
   } else {
     ret <- paste("No residuals_", form[1], " is available.\n", sep = "")
   }
@@ -36,19 +44,21 @@ residuals_marxss <- function(x, type, standardization, clean, ...) {
   data.dims <- model.dims[["y"]]
   nn <- data.dims[1]
   TT <- data.dims[2]
-  resids <- MARSSresiduals(x, type=type, ...)
-  tmp <- apply(resids$var.residuals, 3, function(x) { takediag(x) })
-  tmp[tmp<0 & abs(tmp)<sqrt(.Machine$double.eps)] <- 0
-  if(is.null(dim(tmp))) tmp <- matrix(tmp, nrow=1)
+  resids <- MARSSresiduals(x, type = type, ...)
+  tmp <- apply(resids$var.residuals, 3, function(x) {
+    takediag(x)
+  })
+  tmp[tmp < 0 & abs(tmp) < sqrt(.Machine$double.eps)] <- 0
+  if (is.null(dim(tmp))) tmp <- matrix(tmp, nrow = 1)
   se.resids <- sqrt(tmp)
-  model.se.resids <-  se.resids[1:nn,,drop=FALSE]
+  model.se.resids <- se.resids[1:nn, , drop = FALSE]
   model.se.resids[is.na(resids$model.residuals)] <- NA
   # First y
   type1 <- paste0("y", type)
   data.names <- attr(model, "Y.names")
-  fit.list <- fitted.marssMLE(x, type = type1, interval="none")
+  fit.list <- fitted.marssMLE(x, type = type1, interval = "none")
   ret <- data.frame(
-    type = paste0("y",type),
+    type = paste0("y", type),
     .rownames = fit.list$.rownames,
     name = "model",
     t = fit.list$t,
@@ -57,16 +67,19 @@ residuals_marxss <- function(x, type, standardization, clean, ...) {
     stringsAsFactors = FALSE
   )
   ret <- cbind(ret,
-               .resids = vec(t(resids$model.residuals)),
-               .sigma = vec(t(model.se.resids))
+    .resids = vec(t(resids$model.residuals)),
+    .sigma = vec(t(model.se.resids))
   )
-  if(standardization=="Cholesky") 
+  if (standardization == "Cholesky") {
     ret <- cbind(ret, .std.resids = vec(t(resids$std.residuals[1:nn, , drop = FALSE])))
-  if(standardization=="marginal") 
+  }
+  if (standardization == "marginal") {
     ret <- cbind(ret, .std.resids = vec(t(resids$mar.residuals[1:nn, , drop = FALSE])))
-  if(standardization=="Block.Cholesky") 
+  }
+  if (standardization == "Block.Cholesky") {
     ret <- cbind(ret, .std.resids = vec(t(resids$bchol.residuals[1:nn, , drop = FALSE])))
-  
+  }
+
   # Second x
   type1 <- paste0("x", type)
   state.names <- attr(model, "X.names")
@@ -74,17 +87,20 @@ residuals_marxss <- function(x, type, standardization, clean, ...) {
   mm <- state.dims[1]
   state.se.resids <- se.resids[(nn + 1):(nn + mm), , drop = FALSE]
   state.resids <- resids$state.residuals
-  if(standardization=="Cholesky") 
+  if (standardization == "Cholesky") {
     state.std.resids <- resids$std.residuals[(nn + 1):(nn + mm), , drop = FALSE]
-  if(standardization=="marginal") 
+  }
+  if (standardization == "marginal") {
     state.std.resids <- resids$mar.residuals[(nn + 1):(nn + mm), , drop = FALSE]
-  if(standardization=="Block.Cholesky") 
+  }
+  if (standardization == "Block.Cholesky") {
     state.std.resids <- resids$bchol.residuals[(nn + 1):(nn + mm), , drop = FALSE]
-  if (type!="tt" && (type=="tT" || !clean)){
-    fit.list <- fitted.marssMLE(x, type = type1, interval="none")
-    fit.list$value <- c(fit.list$.x[2:TT],NA)
+  }
+  if (type != "tt" && (type == "tT" || !clean)) {
+    fit.list <- fitted.marssMLE(x, type = type1, interval = "none")
+    fit.list$value <- c(fit.list$.x[2:TT], NA)
     ret2 <- data.frame(
-      type = paste0("x",type),
+      type = paste0("x", type),
       .rownames = fit.list$.rownames,
       name = "state",
       t = fit.list$t,
@@ -97,7 +113,7 @@ residuals_marxss <- function(x, type, standardization, clean, ...) {
     )
     ret <- rbind(ret, ret2)
   }
-  
+
   class(ret) <- c("marssResiduals", "data.frame")
   attr(ret, "standardization") <- standardization
   attr(ret, "residual.type") <- type
@@ -111,4 +127,4 @@ residuals_dfa <- function(x, type, standardization, clean, ...) {
 
 residuals_marss <- function(x, type, standardization, clean, ...) {
   return(residuals_marxss(x, type, standardization, clean))
-}
\ No newline at end of file
+}
