@@ -410,9 +410,9 @@ is.zero <- function(x) {
   (abs(x) < .Machine$double.eps)
 }
 
-is.unitcircle <- function(x, tol=.Machine$double.eps^0.5){
+is.unitcircle <- function(x, tol = .Machine$double.eps^0.5) {
   eigval <- eigen(x, only.values = TRUE)$values
-  all(abs(eigval) <= 1+tol)
+  all(abs(eigval) <= 1 + tol)
 }
 
 is.wholenumber <- function(x, tol = .Machine$double.eps^0.5) {
@@ -426,9 +426,11 @@ is.wholenumber <- function(x, tol = .Machine$double.eps^0.5) {
   return(test)
 }
 
-is.timevarying <- function(MLEobj){
+is.timevarying <- function(MLEobj) {
   model.dims <- attr(MLEobj$marss, "model.dims")[attr(MLEobj[["marss"]], "par.names")]
-  lapply(model.dims, function(x){x[3] != 1})
+  lapply(model.dims, function(x) {
+    x[3] != 1
+  })
 }
 
 vec <- function(x) {
@@ -638,9 +640,9 @@ fixed.free.to.formula <- function(fixed, free, dim) { # dim is the 1st and 2nd d
   Tmax <- max(Tmax, dim(fixed)[3], dim(free)[3])
 
   # turns a fixed/free pair to a list (possibly time-varying) matrix describing that MARSS parameter structure
-  if(dim(free)[2] != 0){
+  if (dim(free)[2] != 0) {
     model <- array(list(0), dim = c(dim(fixed)[1], dim(fixed)[2], Tmax))
-  }else{
+  } else {
     model <- array(0, dim = c(dim(fixed)[1], dim(fixed)[2], Tmax))
   }
   for (t in 1:Tmax) {
@@ -683,12 +685,12 @@ marssMODEL.to.list <- function(MODELobj) {
   model.elem <- attr(MODELobj, "par.names")
   # set up the constr type list with an element for each par name and init val of "none"
   model.list <- list()
-  
+
   for (elem in model.elem) {
     model.list[[elem]] <- fixed.free.to.formula(fixed[[elem]], free[[elem]], model.dims[[elem]][1:2])
   }
-  dim(model.list[["c"]]) <- model.dims[["c"]][c(1,3)]
-  dim(model.list[["d"]]) <- model.dims[["d"]][c(1,3)]
+  dim(model.list[["c"]]) <- model.dims[["c"]][c(1, 3)]
+  dim(model.list[["d"]]) <- model.dims[["d"]][c(1, 3)]
   return(model.list)
 }
 
@@ -762,15 +764,17 @@ sub3D <- function(x, t = 1) {
 }
 
 # replace 0 diags with 0 row/cols; no error checking.  Need square symm matrix
-pcholinv <- function(x, chol=TRUE) {
-  if(all(!x)) return(x)
+pcholinv <- function(x, chol = TRUE) {
+  if (all(!x)) {
+    return(x)
+  }
   dim.x <- dim(x)[1]
   diag.x <- x[1 + 0:(dim.x - 1) * (dim.x + 1)]
   if (any(diag.x == 0)) {
     if (any(diag.x != 0)) {
-      if(chol){
+      if (chol) {
         b <- chol2inv(chol(x[diag.x != 0, diag.x != 0]))
-      }else{
+      } else {
         b <- solve(x[diag.x != 0, diag.x != 0])
       }
       OMG.x <- diag(1, dim.x)[diag.x != 0, , drop = FALSE]
@@ -779,9 +783,9 @@ pcholinv <- function(x, chol=TRUE) {
       inv.x <- matrix(0, dim.x, dim.x)
     }
   } else {
-    if(chol){
+    if (chol) {
       inv.x <- chol2inv(chol(x))
-    }else{
+    } else {
       inv.x <- solve(x)
     }
   }
@@ -867,20 +871,20 @@ all.equal.vector <- function(x) {
 }
 
 # returns a vector with 0s and 1s showing which x are fully spec by the data
-fully.spec.x <- function(Z, R){
+fully.spec.x <- function(Z, R) {
   m <- dim(Z)[2]
   diag.R <- takediag(R)
   Z.R0 <- Z[diag.R == 0, , drop = FALSE]
   Z.R.not.0 <- Z[diag.R != 0, , drop = FALSE]
   # The Z cols where there is a val; and where rows have a val
-  Z.R0.n0 <- Z.R0[rowSums(Z.R0 != 0) != 0, colSums(Z.R0 != 0) != 0, drop = FALSE] 
+  Z.R0.n0 <- Z.R0[rowSums(Z.R0 != 0) != 0, colSums(Z.R0 != 0) != 0, drop = FALSE]
   # If more rows than columns, over-constrained
   dimZ00 <- dim(Z.R0.n0)
   if (dimZ00[1] > dimZ00[2]) {
     return(list(ok = FALSE, errors = "Some R diagonal elements are 0, and Z is such that model is over-determined."))
   }
   # must be invertible if square and not 0x0
-  if (dimZ00[1] == dimZ00[2] & dimZ00[1]!=0) { 
+  if (dimZ00[1] == dimZ00[2] & dimZ00[1] != 0) {
     Ck <- det(Z.R0.n0)
     if (Ck == 0) {
       return(list(ok = FALSE, errors = "Some R diagonal elements are 0, but Z is such that model is indeterminate in this case."))
@@ -888,19 +892,19 @@ fully.spec.x <- function(Z, R){
   }
   # If got here, Z.R0.n0 is ok. Make matrix to zero out determined x in Vtt
   Z1 <- Z.R0
-  detx <- rep(1,m) #1 means NOT fully specified by data
+  detx <- rep(1, m) # 1 means NOT fully specified by data
   # Is there any y where R=0 where there only one x in that row? Then that x is fixed.
   # Set the Z col for that x to 0 (fixed). And repeat. Will have to do at most m iterations to find all
   # the x that are fully specified by the data.
-  for(i in 1:m){
-    tmp <-  (rowSums(Z1 != 0)==1)
-    if(!any(tmp)) break
-    tmp <- (rowSums(Z1 != 0)==1) %*% (Z1!=0)
+  for (i in 1:m) {
+    tmp <- (rowSums(Z1 != 0) == 1)
+    if (!any(tmp)) break
+    tmp <- (rowSums(Z1 != 0) == 1) %*% (Z1 != 0)
     Z1 <- Z1 %*% makediag(!tmp)
   }
   # Any Z1 cols that are 0 are fully spec and should be 0
   # Unless the Z.R0 column is all 0, meaning that x is not affected by R=0 at all
-  detx <- ifelse(colSums(Z1 != 0 ) == 0 & colSums(Z.R0 != 0 ) != 0, 0, 1)
+  detx <- ifelse(colSums(Z1 != 0) == 0 & colSums(Z.R0 != 0) != 0, 0, 1)
   return(list(ok = TRUE, detx = detx))
 }
 
@@ -966,7 +970,7 @@ str_replace <- function(string, pattern, replacement) {
 
 ################################################################
 
-zscore <- function(x) {
+zscore <- function(x, mean.only = FALSE) {
   ismat <- is.matrix(x) # else is vector
   if (ismat) {
     Sigma <- sqrt(apply(x, 1, var, na.rm = TRUE))
@@ -975,31 +979,31 @@ zscore <- function(x) {
     Sigma <- sqrt(var(x, na.rm = TRUE))
     x.bar <- mean(x, na.rm = TRUE)
   }
-  x.z <- (x - x.bar) * (1 / Sigma)
+  x.z <- (x - x.bar)
+  if (!mean.only) x.z <- (x - x.bar) * (1 / Sigma)
   if (ismat) rownames(x.z) <- rownames(x)
   x.z
 }
 
-############# Function to make a diagonal matrix; 
+############# Function to make a diagonal matrix;
 # exported function to make diagonal list matrix. Slower than makediag()
 # which is only for numeric x
-ldiag <- function(x, nrow = NA)
-{
+ldiag <- function(x, nrow = NA) {
   if (length(x) == 1) {
     return(matrix(x, nrow, nrow))
   }
-  if (!is.vector(x)) { 
+  if (!is.vector(x)) {
     stop("mdiag: x is not vector.\n", call. = FALSE)
   }
   if (is.na(nrow)) nrow <- length(x)
-  if(is.list(x)){
-    if(!all(unlist(lapply(x, length))==1)) stop("mdiag: all elements in x list must be length 1.\n", call. = FALSE)
+  if (is.list(x)) {
+    if (!all(unlist(lapply(x, length)) == 1)) stop("mdiag: all elements in x list must be length 1.\n", call. = FALSE)
   }
   tmp <- matrix(list(0), nrow, nrow)
   diag(tmp) <- x
   return(tmp)
 }
 
-MARSS.out <- function(){
-  #Null function for man file
+MARSS.out <- function() {
+  # Null function for man file
 }
